==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algorith/nmible.f <==
      SUBROUTINE NMIBLE(NIVEAU, 
     &                  PREMIE, MAILLA, DEFICO, OLDGEO, NEWGEO,
     &                  DEPMOI, DEPGEO, MAXB,   DEPLAM,
     &                  COMGEO, CSEUIL, COBCA, 
     &                  NEQ   , DEPDEL, DDEPLA, DEPPLU, LIGRCF,
     &                  CARTCF, MODELE, LISCHA, SOLVEU, NUMEDD, 
     &                  MCONEL, SCONEL, MEMASS, MASSE,
     &                  VITPLU, ACCPLU, VITINI, ACCINI, CMD, INST) 

C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 31/08/2004   AUTEUR JMBHH01 J.M.PROIX 
C ======================================================================
C COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C RESPONSABLE PBADEL P.BADEL
C TOLE CRP_21

      IMPLICIT NONE

      LOGICAL      PREMIE
      INTEGER      NIVEAU,MAXB(4),COMGEO,CSEUIL,COBCA,NEQ
      CHARACTER*8  MAILLA,MCONEL,SCONEL
      CHARACTER*16 CMD
      CHARACTER*19 LIGRCF,CARTCF,LISCHA,SOLVEU
      CHARACTER*24 DEFICO,OLDGEO,NEWGEO,DEPMOI,DEPGEO,DEPLAM
      CHARACTER*24 DEPDEL,DDEPLA,DEPPLU,MODELE,NUMEDD
      CHARACTER*24 MEMASS,MASSE, ACCPLU,VITPLU,ACCINI,VITINI
      REAL*8 INST(3)
C ----------------------------------------------------------------------
C
C   STAT_NON_LINE : ROUTINE D'AIGUILLAGE DES ITERATIONS SE SITUANT
C                   ENTRE LES PAS DE TEMPS ET L'EQUILIBRE
C
C                   POUR LE MOMENT, SERT A LA METHODE CONTINUE DE
C                   CONTACT
C
C                   SERVIRA DANS L'AVENIR POUR LES CALCULS DE
C                   SENSIBILITE
C
C                   LES ITERATIONS ONT LIEU ENTRE CETTE ROUTINE
C                   (NMIBLE) ET SA COUSINE (NMTBLE) QUI COMMUNIQUENT
C                   POUR LE MOMENT PAR LA VARIABLE NIVEAU
C
C   IN
C
C   OUT
C -------------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ----------------
C
      CHARACTER*32       JEXNUM , JEXNOM , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C -------------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ----------------

      IF (NIVEAU.LT.0) GOTO 9999
      
      GO TO (101,102,103,104) NIVEAU

 104  CONTINUE
 
C -- VITINI, ACCINI Champs utiles pour la methode continue en dynamique
      IF (CMD(1:4).EQ.'DYNA') THEN
        CALL COPISD('CHAMP_GD','V',VITPLU,VITINI)
        CALL COPISD('CHAMP_GD','V',ACCPLU,ACCINI)
      ENDIF  
  
      CALL DONNCO(MAILLA,OLDGEO,NEWGEO,DEPMOI,DEFICO,DEPGEO,MAXB)

C -- BOUCLE GEOMETRIQUE (CONTACT ECP)

      COMGEO = 0
 103  CONTINUE
      COMGEO = COMGEO + 1
C
      CALL MAPPAR(PREMIE,MAILLA,DEFICO,OLDGEO,NEWGEO,COMGEO,DEPGEO)

C -- BOUCLE SUR LES SEUILLS DE FROTTEMENT (CONTACT ECP)

      CSEUIL = 0
      IF (MAXB(4).EQ.1) GOTO 666
      CALL COPISD('CHAMP_GD','V',DEPMOI,DEPLAM)
 102  CONTINUE
      CSEUIL = CSEUIL + 1
      CALL NMIMPR('IMPR','BCL_SEUIL',' ',0.D0,CSEUIL)

C -- BOUCLE DE CONTRAINTES ACTIVES (CONTACT ECP)

 666  CONTINUE
      COBCA = 0
 101  CONTINUE

C -- 
      IF (CMD(1:4).EQ.'DYNA') THEN
        CALL COPISD('CHAMP_GD','V',VITINI,VITPLU)
        CALL COPISD('CHAMP_GD','V',ACCINI,ACCPLU)
      ENDIF 
      
      COBCA = COBCA + 1
      CALL NMIMPR('IMPR','BCL_CTACT',' ',0.D0,COBCA)
      CALL CONLIG(NEQ,   DEPDEL, DDEPLA, DEPMOI, DEPPLU,
     &           DEFICO, MAILLA, LIGRCF, CARTCF, MODELE,
     &           LISCHA, SOLVEU, NUMEDD, MCONEL, SCONEL, 
     &           MEMASS, MASSE, PREMIE,CMD,INST)

9999  CONTINUE

      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algorith/nmible.f <==
      SUBROUTINE NMIBLE(NIVEAU, 
     &                  PREMIE, MAILLA, DEFICO, OLDGEO, NEWGEO,
     &                  DEPMOI, DEPGEO, MAXB,   DEPLAM,
     &                  COMGEO, CSEUIL, COBCA, 
     &                  NEQ   , DEPDEL, DDEPLA, DEPPLU, LIGRCF,
     &                  CARTCF, MODELE, LISCHA, SOLVEU, NUMEDD, 
     &                  MCONEL, SCONEL, MEMASS, MASSE,
     &                  VITPLU, ACCPLU, VITINI, ACCINI, CMD,
     &                  INST,  ICONTX) 

C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 25/01/2005   AUTEUR GENIAUT S.GENIAUT 
C ======================================================================
C COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C RESPONSABLE PBADEL P.BADEL
C TOLE CRP_21

      IMPLICIT NONE

      LOGICAL      PREMIE
      INTEGER      NIVEAU,MAXB(4),COMGEO,CSEUIL,COBCA,NEQ,ICONTX
      CHARACTER*8  MAILLA,MCONEL,SCONEL
      CHARACTER*16 CMD
      CHARACTER*19 LIGRCF,CARTCF,LISCHA,SOLVEU
      CHARACTER*24 DEFICO,OLDGEO,NEWGEO,DEPMOI,DEPGEO,DEPLAM
      CHARACTER*24 DEPDEL,DDEPLA,DEPPLU,MODELE,NUMEDD
      CHARACTER*24 MEMASS,MASSE, ACCPLU,VITPLU,ACCINI,VITINI
      REAL*8 INST(3)
C ----------------------------------------------------------------------
C
C   STAT_NON_LINE : ROUTINE D'AIGUILLAGE DES ITERATIONS SE SITUANT
C                   ENTRE LES PAS DE TEMPS ET L'EQUILIBRE
C
C                   POUR LE MOMENT, SERT A LA METHODE CONTINUE DE
C                   CONTACT
C
C                   SERVIRA DANS L'AVENIR POUR LES CALCULS DE
C                   SENSIBILITE
C
C                   LES ITERATIONS ONT LIEU ENTRE CETTE ROUTINE
C                   (NMIBLE) ET SA COUSINE (NMTBLE) QUI COMMUNIQUENT
C                   POUR LE MOMENT PAR LA VARIABLE NIVEAU
C
C   IN
C
C   OUT
C -------------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ----------------
C
      CHARACTER*32       JEXNUM , JEXNOM , JEXATR
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C -------------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ----------------

      IF (NIVEAU.LT.0) GOTO 9999
      
      GO TO (101,102,103,104) NIVEAU

 104  CONTINUE
 
C -- VITINI, ACCINI Champs utiles pour la methode continue en dynamique
      IF (CMD(1:4).EQ.'DYNA') THEN
        CALL COPISD('CHAMP_GD','V',VITPLU,VITINI)
        CALL COPISD('CHAMP_GD','V',ACCPLU,ACCINI)
      ENDIF  
  
      CALL DONNCO(MAILLA,OLDGEO,NEWGEO,DEPMOI,DEFICO,DEPGEO,MAXB)

C -- BOUCLE GEOMETRIQUE (CONTACT ECP)

      COMGEO = 0
 103  CONTINUE
      COMGEO = COMGEO + 1
C
C     APPARARIEMENT
      IF (ICONTX.EQ.0) THEN 
        CALL MAPPAR(PREMIE,MAILLA,DEFICO,OLDGEO,NEWGEO,COMGEO,DEPGEO)
      ENDIF

C -- BOUCLE SUR LES SEUILLS DE FROTTEMENT (CONTACT ECP)
C     MAXB(4)=1 SI FROTTEMENT='SANS'
C     MAXB(4)=3 SI FROTTEMENT='COULOMB'

      CSEUIL = 0
      IF (MAXB(4).EQ.1) GOTO 666
      
      CALL COPISD('CHAMP_GD','V',DEPMOI,DEPLAM)
 102  CONTINUE
      CSEUIL = CSEUIL + 1
      CALL NMIMPR('IMPR','BCL_SEUIL',' ',0.D0,CSEUIL)

C -- BOUCLE DE CONTRAINTES ACTIVES (CONTACT ECP)

 666  CONTINUE
      COBCA = 0
 101  CONTINUE

C -- 
      IF (CMD(1:4).EQ.'DYNA') THEN
        CALL COPISD('CHAMP_GD','V',VITINI,VITPLU)
        CALL COPISD('CHAMP_GD','V',ACCINI,ACCPLU)
      ENDIF 
      
      COBCA = COBCA + 1
      CALL NMIMPR('IMPR','BCL_CTACT',' ',0.D0,COBCA)

      IF (ICONTX.EQ.0) THEN
        CALL CONLIG(NEQ,   DEPDEL, DDEPLA, DEPMOI, DEPPLU,
     &              DEFICO, MAILLA, LIGRCF, CARTCF, MODELE,
     &              LISCHA, SOLVEU, NUMEDD, MCONEL, SCONEL, 
     &              MEMASS, MASSE, PREMIE,CMD,INST)
      ELSE
C       CAS X-FEM
        CALL XCONLI(NEQ,DEPDEL,DDEPLA,DEPMOI,DEPPLU,PREMIE,MODELE(1:8),
     &                  MAILLA,DEFICO,MCONEL,SCONEL)
      ENDIF


9999  CONTINUE

      END
